import os
import sys
import argparse
from datetime import date
from pytrends.request import TrendReq
import matplotlib.pyplot as plt

def f():

    pytrends = TrendReq(hl='en_US', tz=360)
    # https://github.com/pat310/google-trends-api/wiki/Google-Trends-Categories

    all_keywords = sys.argv[1:]

    today = date.today()
    frame = f'2004-01-01 {today.strftime("%Y-%m-%d")}'

    # cat=31 = programming
    pytrends.build_payload(all_keywords, timeframe=frame, geo='')


    df = pytrends.interest_over_time()
    df.head(20)

    plt.style.use('dark_background')
    plt.figure().patch.set_facecolor('#121212')
    plt.axes().set_facecolor('#080808')

    linewidth = 1
    colors = ['orange', 'teal', 'crimson', 'magenta', 'skyblue']

    for i, x in enumerate(all_keywords):
        plt.plot(df[x], color=colors[i], label=x, linewidth=linewidth)

    plt.legend()
    plt.grid(color='#303030')

    # automatically save the image.
    plt.savefig(f'{"_".join(x for x in all_keywords)}.png', dpi=120)

    plt.show()


def start():
    parser = argparse.ArgumentParser(description='Enter term.')
    for item in sys.argv[1:]:
        parser.add_argument(f'{item}', type=str, help='enter a term')

    args = parser.parse_args()
    f()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['atrends']

package_data = \
{'': ['*']}

install_requires = \
['matplotlib>=3.4.3,<4.0.0', 'pytrends>=4.7.3,<5.0.0']

entry_points = \
{'console_scripts': ['atrends = atrends.main:start',
                     'trends = atrends.main:start']}

setup_kwargs = {
    'name': 'atrends',
    'version': '0.1.1',
    'description': 'A PyTrends script to access the Google Trends API and return a plot.',
    'long_description': '# CLI for Google Trends\n\nUse this to quickly access the [Google Trends API](https://trends.google.com/trends/) via Command Line.\n\n## Installation\n```bash\npip install atrends\n```\n\n## Usage\n\n#### Run `trends` with any number of arguments\n\n## Example\n```bash\ntrends flask django react\n```\n\n![](https://i.imgur.com/JzzNAZU.png)\n\n## Custom:\nEdit the category, timeframe, colors, lines, in main.py\n',
    'author': 'davidshivaji',
    'author_email': 'davidshivaji@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
